==> sceptre-00.317.tar.gz: x1/getck.f <==
CSECT   GETCK
C       28 MAR 73
 
       SUBROUTINE GETCK (ISTAR,LAST,NOCARD)
 
C      SUBROUTINE TO ASSIGN TAPES, GET A CARD, CHECK CARD FOR GROUP
C      CALLING SEQUENCE IS
C                 ISTART IS STARTING POSITION IN RETURNED DATA
C                 ILAST IS FINAL POSITION OF RETURNED DATA
C                 NOCARD IS ONE FOR NORMAL RETURN, TWO IF A GROUP
C                    IS LOCATED OR MODEL DATA IS EXHAUSTED
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z), INTEGER (I-N)
 
	include 'tapes.inc'

      COMMON /SAVER/  EW,NEWGRP,ISTSAV,ILTSAV,JSKIP,SAVE(72)
         CHARACTER*8  SAVE
      COMMON /BUFERS/ SPLTBF(72),BLNKBF(72),PACKBF(12),ISTART,ILAST
         CHARACTER*8  SPLTBF,BLNKBF,PACKBF
      COMMON /MODATA/ ANAMES(3),CKTDES(4),PRJ(62),ANODES(25,2),NMDNOD,
     *                MDPRNT,SUPRES(10),EQUCHG(15,2),TBLCHG(15,2),
     *                NTBLCH,NEQUCH,NSUPRS,MDTAPE,MDLEN,MDUSED,IALL,
     *                KCHNGE,NTEMP,NMDCHR
C     MODE CHECK INITIALIZATION
      CHARACTER*8     CKMOD(2,7)
      CHARACTER*8     DEND(3)
C     GROUP CHECK INITIALIZATION
      CHARACTER*8     CKGRP (3,10)
      CHARACTER*8     BLANKS,TEMP,TEMPO
      INTEGER         TAPE,iadr(12)
      character*6     wsuffx,wbuff*24
      logical         lcomnt,lfirst
 
      data lfirst /.true./
      DATA CKMOD /'MODELD  ','ESCRIP  ',
     1            'CIRCUI  ','TDESCR  ',
     2            'CONTIN  ','UE      ',
     3            'RE-OUT  ','PUT     ',
     4            'RERUND  ','ESCRIP  ',
     5            'END     ','        ',
     6            'RELOAD  ','        '/
      DATA DEND  /'E','N','D'/
      DATA CKGRP /'ELEMEN  ','TS      ','        ',
     1            'RUNCON  ','TROLS   ','        ',
     2            'OUTPUT  ','S       ','        ',
     3            'FUNCTI  ','ONS     ','        ',
     4            'DEFINE  ','DPARAM  ','ETERS   ',
     5            'INITIA  ','LCONDI  ','TIONS   ',
     6            'SENSIT  ','IVITY   ','        ',
     7            'OPTIMI  ','ZATION  ','        ',
     8            'WORSTC  ','ASE     ','        ',
     9            'MONTEC  ','ARLO    ','        '/

C     MAXDAT IS THE MAXIMUM CHARACTERS PER CARD.
      DATA MAXDAT,BLANKS /72,' '/
 
C     ASSIGN INPUT TAPE AND RESET PRINT CONTROL
C     CHECK THE SKIP INDICATOR AND EXIT IF FOUND
 
C	if (lfirst) then
C		lfirst = .false.
C		ierror=jb77eq ("eth0",maxadr,wbuff)
C		do 100 i1=1,maxadr
C			iadr(i1)=i1*17+ichar(wbuff(i1:i1))+256
C100		continue
C		do 200 i1=1,maxadr
C			iadr(i1)=iadr(i1)+iadr(maxadr+1-i1)
C200		continue
C		do 300 i1=1,maxadr
C		iadr(maxadr+i1)=iadr(i1)*iadr(i1+1)
C300		continue
C		write (wbuff,'(12z2.2)')(mod(iadr(i1),256),
C    &			i1=1,2*maxadr)
C		if (wbuff.ne.spltbf(1)(1:24)) then
C			write (iqqout,301)
C			print 301
C			stop
C301			format ('0EXEC1: illegal configuration file')
C		end if
C	end if

      NOCARD = 1
      TAPE=iqqinp
      wsuffx=' '
      IPRINT = 0
      IF (JSKIP.EQ.2) GO TO 400
 
C     CHECK FOR MODEL MODE
 
  120 IF (NMDCHR .LE. 0) GO TO 1
 
C     CHECK THE NUMBER OF MODEL CARDS ALREADY USED
 
      IF (MDUSED .LT. MDLEN) GO TO 190
 
C     RESET MODEL MODE INDICATOR
 
      NMDCHR = 0
      MDPRNT=0
      MDLEN=0
 
C     SET GROUP INDICATOR TO ELEMENTS AND TURN ON NOCARD
 
      NOCARD = 2
      NEWGRP = 2
 
C     CHECK FOR DATA IN SAVE BUFFER AND RESTORE ANY THERE
 
      IF (ISTSAV .GT. ILTSAV .OR. ISTSAV .LE. 0) GO TO 1
      DO 150 I= ISTSAV,ILTSAV
  150 BLNKBF (I) = SAVE(I)
 
C     RESTORE START AND LAST CHARACTER
 
      ISTART = ISTSAV
      ILAST  = ILTSAV
      ISTSAV = ILTSAV + 1
      GO TO 500
 
C     ASSIGN MODEL TAPE AND PRINT CONTROL, UPDATE MODEL CARD COUNTER
 
  190 TAPE=iqqmdl
      wsuffx='<model'
      IPRINT = MDPRNT
      MDUSED = MDUSED + 1
 
C     READ THE NEW CARD.
 
    1 READ (TAPE,5,END=3681) SPLTBF
    5 FORMAT (72A1)
      GO TO 6
 3681 DO 11 N=4,72
   11 SPLTBF(N)=BLANKS
      DO 12 N=1,3
   12 SPLTBF(N)=DEND(N)
    6 continue
 
C     PRINT CARD IF INDICATOR IS ON.
 
      IF (IPRINT.EQ.0) WRITE (iqqout,10) SPLTBF,wsuffx
   10 FORMAT (1H ,72A1,a)
 
C     LOAD DATA INTO BLNKBF WITH PURGED BLANKS.
C     erase comment after ';'
 
      LC=0
      lcomnt=.false.
      DO 15 N=1,MAXDAT
         BLNKBF(N)=BLANKS
         if (spltbf(n) .eq. ';') lcomnt=.true.
         if (lcomnt) spltbf(n)=blanks
         IF (SPLTBF(N).EQ.BLANKS) GO TO 15
         LC=LC+1
         BLNKBF(LC)=SPLTBF(N)
   15 CONTINUE
 
C     IF A BLANK CARD IS READ, A NEW CARD IS READ.
 
      IF (LC.EQ.0) GO TO 1
      ILAST=LC
 
C     CALL ROUTINE TO PACK BCD DATA 6 CHAR. PER WORD
 
      CALL CPYSP (BLNKBF,72,' ',0,' ',0,PACKBF,NWORD)
      ISTART = 1
      DO 25 K=1,7
      TEMP=PACKBF(1)
      IF (TEMP.NE.CKMOD(1,K)) GO TO 25
      TEMPO=PACKBF(2)
      IF ((ILAST .GT.6).AND.(TEMPO.NE.CKMOD(2,K)))GO TO 25
      NEWGRP=-K
      NOCARD=2
      GO TO 400
   25 CONTINUE
 
C     CHECK FOR GROUP CARD
 
      IF (ILAST - 17) 26,27,500
   26 IF (ILAST - 7) 500,27,27
   27 DO 37 I = 1,10
      DO 36 J=1,3
   36 IF ((CKGRP(J,I).NE.BLANKS) .AND.
     *    (CKGRP(J,I).NE.PACKBF(J))) GO TO 37
 
C     STORE GROUP INDICATOR AND SET CARD FOUND INDICATOR
 
      NEWGRP=I+1
      NOCARD=2
      IF (NMDCHR.LT.0) GO TO 500
      GO TO 120
   37 CONTINUE
      GO TO 500
 
C     RESET SKIP INDICATOR
 
  400 JSKIP = 1
  500 ISTAR=ISTART
      LAST=ILAST
      RETURN
 
      END

==> sceptre-2012.061.tar.gz: x1/getck.f <==
CSECT   GETCK
C       28 MAR 73
 
       SUBROUTINE GETCK (ISTAR,LAST,NOCARD)
 
C      SUBROUTINE TO ASSIGN TAPES, GET A CARD, CHECK CARD FOR GROUP
C      CALLING SEQUENCE IS
C                 ISTART IS STARTING POSITION IN RETURNED DATA
C                 ILAST IS FINAL POSITION OF RETURNED DATA
C                 NOCARD IS ONE FOR NORMAL RETURN, TWO IF A GROUP
C                    IS LOCATED OR MODEL DATA IS EXHAUSTED
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z), INTEGER (I-N)
 
      include 'tapes.inc'

      COMMON /SAVER/  EW,NEWGRP,ISTSAV,ILTSAV,JSKIP,SAVE(72)
         CHARACTER*8  SAVE
      COMMON /BUFERS/ SPLTBF(72),BLNKBF(72),PACKBF(12),ISTART,ILAST
         CHARACTER*8  SPLTBF,BLNKBF,PACKBF
      COMMON /MODATA/ ANAMES(3),CKTDES(4),PRJ(62),ANODES(25,2),NMDNOD,
     *                MDPRNT,SUPRES(10),EQUCHG(15,2),TBLCHG(15,2),
     *                NTBLCH,NEQUCH,NSUPRS,MDTAPE,MDLEN,MDUSED,IALL,
     *                KCHNGE,NTEMP,NMDCHR
C     MODE CHECK INITIALIZATION
      CHARACTER*8     CKMOD(2,7)
      CHARACTER*8     DEND(3)
C     GROUP CHECK INITIALIZATION
      CHARACTER*8     CKGRP (3,10)
      CHARACTER*8     BLANKS,TEMP,TEMPO
      INTEGER         TAPE
      character*6     wsuffx
      logical         lcomnt
 
      DATA CKMOD /'MODELD  ','ESCRIP  ',
     1            'CIRCUI  ','TDESCR  ',
     2            'CONTIN  ','UE      ',
     3            'RE-OUT  ','PUT     ',
     4            'RERUND  ','ESCRIP  ',
     5            'END     ','        ',
     6            'RELOAD  ','        '/
      DATA DEND  /'E','N','D'/
      DATA CKGRP /'ELEMEN  ','TS      ','        ',
     1            'RUNCON  ','TROLS   ','        ',
     2            'OUTPUT  ','S       ','        ',
     3            'FUNCTI  ','ONS     ','        ',
     4            'DEFINE  ','DPARAM  ','ETERS   ',
     5            'INITIA  ','LCONDI  ','TIONS   ',
     6            'SENSIT  ','IVITY   ','        ',
     7            'OPTIMI  ','ZATION  ','        ',
     8            'WORSTC  ','ASE     ','        ',
     9            'MONTEC  ','ARLO    ','        '/

C     MAXDAT IS THE MAXIMUM CHARACTERS PER CARD.
      DATA MAXDAT,BLANKS /72,' '/
 
C     ASSIGN INPUT TAPE AND RESET PRINT CONTROL
C     CHECK THE SKIP INDICATOR AND EXIT IF FOUND
 
      NOCARD = 1
      TAPE=iqqinp
      wsuffx=' '
      IPRINT = 0
      IF (JSKIP.EQ.2) GO TO 400
 
C     CHECK FOR MODEL MODE
 
  120 IF (NMDCHR .LE. 0) GO TO 1
 
C     CHECK THE NUMBER OF MODEL CARDS ALREADY USED
 
      IF (MDUSED .LT. MDLEN) GO TO 190
 
C     RESET MODEL MODE INDICATOR
 
      NMDCHR = 0
      MDPRNT=0
      MDLEN=0
 
C     SET GROUP INDICATOR TO ELEMENTS AND TURN ON NOCARD
 
      NOCARD = 2
      NEWGRP = 2
 
C     CHECK FOR DATA IN SAVE BUFFER AND RESTORE ANY THERE
 
      IF (ISTSAV .GT. ILTSAV .OR. ISTSAV .LE. 0) GO TO 1
      DO 150 I= ISTSAV,ILTSAV
  150 BLNKBF (I) = SAVE(I)
 
C     RESTORE START AND LAST CHARACTER
 
      ISTART = ISTSAV
      ILAST  = ILTSAV
      ISTSAV = ILTSAV + 1
      GO TO 500
 
C     ASSIGN MODEL TAPE AND PRINT CONTROL, UPDATE MODEL CARD COUNTER
 
  190 TAPE=iqqmdl
      wsuffx='<model'
      IPRINT = MDPRNT
      MDUSED = MDUSED + 1
 
C     READ THE NEW CARD.
 
    1 READ (TAPE,5,END=3681) SPLTBF
    5 FORMAT (72A1)
      GO TO 6
 3681 DO 11 N=4,72
   11 SPLTBF(N)=BLANKS
      DO 12 N=1,3
   12 SPLTBF(N)=DEND(N)
    6 continue
 
C     PRINT CARD IF INDICATOR IS ON.
 
      IF (IPRINT.EQ.0) WRITE (iqqout,10) SPLTBF,wsuffx
   10 FORMAT (1H ,72A1,a)
 
C     LOAD DATA INTO BLNKBF WITH PURGED BLANKS.
C     erase comment after ';'
 
      LC=0
      lcomnt=.false.
      DO 15 N=1,MAXDAT
         BLNKBF(N)=BLANKS
         if (spltbf(n) .eq. ';') lcomnt=.true.
         if (lcomnt) spltbf(n)=blanks
         IF (SPLTBF(N).EQ.BLANKS) GO TO 15
         LC=LC+1
         BLNKBF(LC)=SPLTBF(N)
   15 CONTINUE
 
C     IF A BLANK CARD IS READ, A NEW CARD IS READ.
 
      IF (LC.EQ.0) GO TO 1
      ILAST=LC
 
C     CALL ROUTINE TO PACK BCD DATA 6 CHAR. PER WORD
 
      CALL CPYSP (BLNKBF,72,' ',0,' ',0,PACKBF,NWORD)
      ISTART = 1
      DO 25 K=1,7
      TEMP=PACKBF(1)
      IF (TEMP.NE.CKMOD(1,K)) GO TO 25
      TEMPO=PACKBF(2)
      IF ((ILAST .GT.6).AND.(TEMPO.NE.CKMOD(2,K)))GO TO 25
      NEWGRP=-K
      NOCARD=2
      GO TO 400
   25 CONTINUE
 
C     CHECK FOR GROUP CARD
 
      IF (ILAST - 17) 26,27,500
   26 IF (ILAST - 7) 500,27,27
   27 DO 37 I = 1,10
      DO 36 J=1,3
   36 IF ((CKGRP(J,I).NE.BLANKS) .AND.
     *    (CKGRP(J,I).NE.PACKBF(J))) GO TO 37
 
C     STORE GROUP INDICATOR AND SET CARD FOUND INDICATOR
 
      NEWGRP=I+1
      NOCARD=2
      IF (NMDCHR.LT.0) GO TO 500
      GO TO 120
   37 CONTINUE
      GO TO 500
 
C     RESET SKIP INDICATOR
 
  400 JSKIP = 1
  500 ISTAR=ISTART
      LAST=ILAST
      RETURN
 
      END
